@@ -34,6 +34,10 @@ class Deployment(Resource):
         # pylint: disable-msg=C0111,W0201
         self.__budget = b
 
+    @lazy_property
+    def catalog_item(self):
+        return self.__catalog_item
+
     @lazy_property
     def label(self):
         return self.__label
